// @flow
import { BigNumber } from "bignumber.js";
import {
  parseCurrencyUnit,
  getCryptoCurrencyById,
  formatCurrencyUnit
} from "../currencies";

const rippleUnit = getCryptoCurrencyById("ripple").units[0];

export const defaultEndpoint = "wss://s2.ripple.com";

export const apiForEndpointConfig = (
  RippleAPI: *, // you must provide {RippleAPI} from "ripple-lib"
  endpointConfig: ?string = null
) => {
  const server = endpointConfig || defaultEndpoint;
  const api = new RippleAPI({ server });
  api.on("error", (errorCode, errorMessage) => {
    console.warn(`Ripple API error: ${errorCode}: ${errorMessage}`);
  });
  return api;
};

export const parseAPIValue = (value: string) =>
  parseCurrencyUnit(rippleUnit, value);

export const parseAPICurrencyObject = ({
  currency,
  value
}: {
  currency: string,
  value: string
}) => {
  if (currency !== "XRP") {
    console.warn(`RippleJS: attempt to parse unknown currency ${currency}`);
    return BigNumber(0);
  }
  return parseAPIValue(value);
};

export const formatAPICurrencyXRP = (amount: BigNumber) => {
  const value = formatCurrencyUnit(rippleUnit, amount, {
    showAllDigits: true,
    disableRounding: true,
    useGrouping: false
  });
  return { currency: "XRP", value };
};
